@@ -59,7 +59,7 @@ options = (
     ('cw_compatibility',
       {'type' : 'yn',
       'default': True,
-      'help': 'specifies if cw_combatibility css must be activated (needed in production)',
+      'help': 'use compat css rules (enable if your application uses views that have not been ported to bootstrap)',
       'group': 'bootstrap', 'level': 0,
       }),
 )
