@@ -39,6 +39,9 @@ uncomment code below if you want to activate automatic test for your cube:
 
 from logilab.common.testlib import TestCase
 
+# this will make sure cubes are in our sys.path
+import cubicweb.devtools
+
 from cubes.bootstrap import monkeypatch_default_value
 
 
