@@ -10,14 +10,13 @@ from cubicweb import view as cwview
 from cubicweb.schema import display_name
 from cubicweb.web.views.bookmark import BookmarksBox
 from cubicweb.web.views.boxes import EditBox
-from cubicweb.web.views import basetemplates
+from cubicweb.web.views.basetemplates import HTMLHeader
 
 from cubicweb.predicates import match_user_groups
 
 BookmarksBox.__select__ = match_user_groups('users', 'managers')
 EditBox.__select__ = EditBox.__select__ & match_user_groups('users', 'managers')
 
-
 # do not wrap cell_calls with <div class="section">
 
 cwview.View.add_div_section = False
@@ -39,7 +38,7 @@ def field(self, label, value, row=True, show_label=True, w=None, tr=True,
         w(u'<td>%s</td>' % value)
     w(u'</tr>')
 
-class BSHTMLHeader(basetemplates.HTMLHeader):
+class BSHTMLHeader(HTMLHeader):
 
     def stylesheets(self):
         super(BSHTMLHeader, self).stylesheets()
@@ -50,7 +49,7 @@ class BSHTMLHeader(basetemplates.HTMLHeader):
 
 def registration_callback(vreg):
     components = (
-        (BSHTMLHeader, basetemplates.HTMLHeader),
+        (BSHTMLHeader, HTMLHeader),
         )
     vreg.register_all(globals().values(), __name__,
                       [new for (new, old) in components])
