@@ -50,7 +50,7 @@ def render_fields(self, w, form, values):
                 self._main_display_fields, w, form)
 
 
-formrenderers.FormRenderer.button_bar_class = u'clearfix form-group'
+formrenderers.FormRenderer.button_bar_class = u'form-group'
 
 class ModalFormRenderer(formrenderers.FormRenderer):
     __regid__ = 'modal-form-renderer'
@@ -93,15 +93,6 @@ class ModalFormRenderer(formrenderers.FormRenderer):
         html.append('</div></div></div>') # close modal-content, modal-dialog, ...
         return u'\n'.join(html)
 
-@monkeypatch(formrenderers.FormRenderer)
-def render_content(self, w, form, values):
-    if self.display_progress_div:
-        w(u'<div id="progress">%s</div>' % self._cw._('validating...'))
-    w(u'<fieldset>')
-    self.render_fields(w, form, values)
-    self.render_buttons(w, form)
-    w(u'</fieldset>')
-
 
 @monkeypatch(formrenderers.FormRenderer)
 def render_help(self, form, field):
@@ -117,7 +108,7 @@ def render_help(self, form, field):
                  "and field as argument (%s)" % field, DeprecationWarning)
             descr = descr(form)
     if descr:
-        help.append('<p class="text-muted">%s</p>' % self._cw._(descr))
+        help.append('<p class="help-block">%s</p>' % self._cw._(descr))
     example = field.example_format(self._cw)
     if example:
         help.append('<p class="form-control-static">(%s: %s)</p>'
@@ -175,18 +166,20 @@ def _render_fields(self, fields, w, form):
         for field in fields:
             error = form.field_error(field)
             control = not hasattr(field, 'control_field') or field.control_field
-            w(u'<div class="form-group %s-%s_row %s">' % (field.name,
+            w(u'<div id="%s-%s_row" class="form-group %s">' % (field.name,
                                                           field.role,
                                                           'error' if error else ''))
             if self.display_label and field.label is not None:
                 w(u'%s' % self.render_label(form, field))
-            if control: # katia : 'control' class no longer exists in bootstrap 3.0.0
-                        # but is used here because of
-                        # 'form-horizontal' bootstrap 2.0.4 css
-                        # backport
-                w(u'<div class="controls">')
-            else:
-                w(u'<div class="controls no-margin">')
+            # Use full width for inlined forms, 9/12 for normal fields
+            base_css = 'col-md-12' if hasattr(field, 'view') else 'col-md-9'
+            if not control:
+                # katia : 'control' class no longer exists in bootstrap 3.0.0
+                # but is used here because of
+                # 'form-horizontal' bootstrap 2.0.4 css
+                # backport
+                base_css += ' nomargin'
+            w(u'<div class="%s">' % base_css)
             w(field.render(form, self))
             if error:
                 self.render_error(w, error)
@@ -204,7 +197,7 @@ def render_label(self, form, field):
         return u''
     label = formrenderers.field_label(form, field)
     attrs = {'for': field.dom_id(form)}
-    attrs['class'] = 'control-label'
+    attrs['class'] = 'col-md-3 control-label'
     if field.required:
         attrs['class'] += ' required'
     return tags.label(label, **attrs)
@@ -216,47 +209,34 @@ def render_buttons(self, w, form):
     """
     if not form.form_buttons:
         return
-    w(u'<div class="form-group"><div class="%s">' % self.button_bar_class)
+    w(u'<div class="%s">' % self.button_bar_class)
     for button in form.form_buttons:
-        w(u'%s' % button.render(form))
-    w(u'</div></div>')
+        w(button.render(form))
+    w(u'</div>')
 
 
 @monkeypatch(formrenderers.EntityFormRenderer)
 def open_form(self, form, values):
-    """creates the form's title
-    """
-    attrs_fs_label = ''
+    attrs_fs_label = u''
     if self.main_form_title:
-        attrs_fs_label = (u'<legend>%s</legend>' %
-                          self._cw._(self.main_form_title))
-    open_form = u'%s%s' % (attrs_fs_label,
-                           super(formrenderers.EntityFormRenderer,
-                                 self).open_form(form, values))
+        attrs_fs_label = u'<h3>%s</h3>' % self._cw._(self.main_form_title)
+    open_form = attrs_fs_label + super(formrenderers.EntityFormRenderer,
+                                       self).open_form(form, values)
     return open_form
 
 
 @monkeypatch(formrenderers.EntityFormRenderer)
 def close_form(self, form, values):
-    """seems dumb but important for consistency w/ close form, and necessary
-    for form renderers overriding open_form to use something else or
-    more than
-    and <form>
-    """
-    return super(formrenderers.EntityFormRenderer, self).close_form(form, values) + ''
+    # needed to remove the '</div>' from the original method
+    return super(formrenderers.EntityFormRenderer, self).close_form(form, values)
 
 
 @monkeypatch(formrenderers.EntityFormRenderer)
 def render_buttons(self, w, form):
-    """let the form buttons be inside a div
-    """
-    if len(form.form_buttons) == 3:
-        w(u'<div class="%s">\n' % self.button_bar_class)
-        w(u'%s %s %s' %
-          tuple(button.render(form) for button in form.form_buttons))
-        w(u'</div>')
-    else:
-        super(formrenderers.EntityFormRenderer, self).render_buttons(w, form)
+    # needed to use our own monkeypatched FormRenderer.render_buttons() which
+    # doesn't need to add a special case when there are 3 buttons to render
+    super(formrenderers.EntityFormRenderer, self).render_buttons(w, form)
+
 
 @monkeypatch(formrenderers.EntityInlinedFormRenderer)
 def open_form(self, w, form, values):
@@ -265,7 +245,8 @@ def open_form(self, w, form, values):
     except KeyError:
         w(u'<div id="div-%(divid)s">' % values)
     else:
-        w(u'<div id="notice-%s" class="notice">%s</div>' % (
+        w(u'<div id="notice-%s" class="notice text-info">'
+          u'<span class="glyphicon glyphicon-info-sign"></span> %s</div>' % (
             values['divid'], self._cw._('click on the box to cancel the deletion')))
     w(u'<div class="iformBody">')
 
